package
Version:
v0.0.0-...-6f578bd
Opens a new window with list of versions in this module.
Published: Jan 11, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
const (
CantFindUser = "Can't find user with nickname '%s'"
)
type Message struct {
Msg string `json:"message"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.